<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:ebTest="http://www.oasis-open.org/tc/ebxml-iic/conformance/tests">
	<xsl:output method="html"/>
	<!-- OASIS/ebXML Test Suite Framework
	       Description: XSLT Style Sheet for transforming ebXML Abstract Test Cases to HTML format
	       Author: Michael Kass
	       Organization: NIST
	       Date: 10/13/2002
	       Version 0.0
	       
	          This file was provided by the National Institute of Standards and Technology. 
	          This software can be redistributed and/or modified freely provided that any 
	          derivative works bear some notice that they are derived from it, and any modified 
	          versions bear some notice that they have been modified.
	        -->
	<xsl:template match="/">
		<head>
			<title>ebXML Test Suite</title>
		</head>
		<table border="2">
			<xsl:apply-templates/>
		</table>
	</xsl:template>
	<xsl:template match="ebTest:TestSuite">
		<tr>
			<td width="10%" align="center">
				<h4>Test Object</h4>
			</td>
			<td width="10%" align="center">
				<h4>ID</h4>
			</td>
			<td width="10%" align="center">
				<h4>Description</h4>
			</td>
			<td width="10%" align="center">
				<h4>Party</h4>
			</td>
			<td width="10%" align="center">
				<h4>Operation</h4>
			</td>
			<td width="50%" align="center">
				<h4>Message Expression</h4>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:TestCase"/>
		<tr>
			<td colspan="1">
				<b>		Test Templates </b>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:Template"/>
	</xsl:template>
	<xsl:template match="ebTest:TestCase">
		<tr>
			<td>
				<b>	Test Case </b>
			</td>
			<td>
				<i>
					<b>
						<xsl:value-of select="@id"/>
					</b>
				</i>
			</td>
			<td>
				<i>
					<b>
						<xsl:value-of select="@description"/>
					</b>
				</i>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:TestStep"/>
	</xsl:template>
	<xsl:template match="ebTest:TestStep">
		<tr>
			<td>TestStep</td>
			<td>
				<xsl:value-of select="position()"/>
			</td>
			<td>
				<xsl:value-of select="@description"/>
			</td>
			<td>
				<xsl:value-of select="@party"/>
			</td>
			<td/>
		</tr>
		<xsl:apply-templates select="ebTest:PutMessage|ebTest:GetMessage"/>
	</xsl:template>
	<xsl:template match="ebTest:PutMessage">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
				<xsl:apply-templates select="ebTest:FileName|ebTest:TemplateRef"/>
			</td>
			<td width="50%">
				<xsl:text> /MIME:Message/MIME:Container[</xsl:text>
				<xsl:apply-templates select="ebTest:MimeHeader|ebTest:MimeHeaderValue"/>
				<xsl:if test="ebTest:MimeHeader"><xsl:text> and </xsl:text></xsl:if>
				<xsl:value-of select="text()"/>
				<xsl:text>]</xsl:text>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:SetPayload"/>
	</xsl:template>
	<xsl:template match="ebTest:SetPayload">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
				<xsl:apply-templates select="ebTest:FileName|ebTest:TemplateRef"/>
			</td>
			<td width="50%">
				<xsl:text/>
				<xsl:apply-templates select="ebTest:MimeHeader|ebTest:MimeHeaderValue|ebTest:Content-ID|ebTest:Content-Location"/>
				<xsl:value-of select="text()"/>
				<xsl:text/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:GetMessage">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
			</td>
			<td width="50%">
				<xsl:text> /MIME:Message/MIME:Container[</xsl:text>
				<xsl:apply-templates select="ebTest:Content-ID|ebTest:Content-Location|ebTest:Index"/>
				<xsl:value-of select="text()"/>
				<xsl:text>]</xsl:text>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:PreCondition|ebTest:ConformanceCondition|ebTest:GetPayload"/>
	</xsl:template>
	<xsl:template match="ebTest:GetPayload">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
			</td>
			<td width="50%">
				<xsl:text> /MIME:Message/MIME:Container[</xsl:text>
				<xsl:apply-templates select="ebTest:Index|ebTest:Signature|ebTest:Content-ID|ebTest:Content-Location"/>
				<xsl:value-of select="text()"/>
				<xsl:text>]</xsl:text>
			</td>
		</tr>
		<xsl:apply-templates select="ebTest:PreCondition|ebTest:ConformanceCondition"/>
	</xsl:template>
	<xsl:template match="ebTest:PreCondition|ebTest:ConformanceCondition">
		<tr bgcolor="BBBBBB">
			<td/>
			<td/>
			<td>
				<xsl:value-of select="@description"/>
			</td>
			<td/>
			<td>
				<xsl:value-of select="local-name()"/>
			</td>
			<td width="50%">
				<xsl:value-of select="."/>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:Template">
		<tr bgcolor="BBBBBB">
			<td colspan="6">
				<blockquote>
					<font color="666600">&lt;ebTest:</font>
					<font color="BB0000">Template</font>
					<font color="880000"> id=</font>
					<font color="000088">
						<b>"<xsl:value-of select="@id"/>"</b>
					</font>&gt;
			<blockquote>
						<font color="666600">&lt;ebTest:</font>
						<font color="BB0000">FileName&gt;</font>
						<xsl:element name="a">
							<xsl:attribute name="href">templates/<xsl:value-of select="ebTest:FileName"/></xsl:attribute>
							<xsl:value-of select="ebTest:FileName"/>
						</xsl:element>
						<font color="666600">&lt;/ebTest:</font>
						<font color="BB0000">FileName&gt;</font>
					</blockquote>
					<font color="666600">&lt;/ebTest:</font>
					<font color="BB0000">Template</font>
				</blockquote>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="ebTest:MimeHeader">
		<xsl:choose>
			<xsl:when test="count(preceding-sibling::*) > 0">
				<xsl:text> and /@</xsl:text>
				<xsl:value-of select="."/>= 
				</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test=". = 'MIMEMessageContent-Type'">
						<xsl:text>../@Content-Type = '</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'MIMEMessageStart'">
						<xsl:text>../@start = '</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>/@</xsl:text>
						<xsl:value-of select="."/>= 
				</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ebTest:MimeHeaderValue">
		<xsl:text>'</xsl:text>
		<xsl:value-of select="."/>
		<xsl:text>'</xsl:text>
	</xsl:template>
	<xsl:template match="ebTest:FileName">
		<xsl:text/>		
		fileName = '<xsl:value-of select="."/>'
	</xsl:template>
	<xsl:template match="ebTest:TemplateRef">
		<xsl:text/>
		templateRef = '<xsl:value-of select="."/>'
	</xsl:template>
	<xsl:template match="ebTest:Content-ID">
		<xsl:choose>
			<xsl:when test="parent::node()[name()='ebTest:SetPayload']">
				<xsl:text>/@Content-Id = '</xsl:text>
			</xsl:when>
			<xsl:when test="parent::node()[name()='ebTest:GetPayload']">
				<xsl:text>/@Content-Id == '</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="parent::node()[name()='ebTest:SetPayload']">
				<xsl:value-of select="."/>
				<xsl:text>' </xsl:text>
			</xsl:when>
			<xsl:when test="parent::node()[name()='ebTest:GetPayload']">
				<xsl:value-of select="."/>
				<xsl:text>' </xsl:text>
				<xsl:text/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="ebTest:Content-Location">
		<xsl:choose>
			<xsl:when test="parent::node()[name()='ebTest:SetPayload']">
				<xsl:text>[/@Content-Location = '</xsl:text>
			</xsl:when>
			<xsl:when test="parent::node()[name()='ebTest:GetPayload']">
				<xsl:text>[/@Content-Location == '</xsl:text>
			</xsl:when>
		</xsl:choose>
		<xsl:value-of select="."/>
		<xsl:text>']</xsl:text>
	</xsl:template>
	<xsl:template match="ebTest:Index">
		<xsl:text/>
		<xsl:value-of select="."/>
	</xsl:template>
	<xsl:template match="ebTest:Signature">
		<xsl:text/>
		signature = <xsl:value-of select="."/>
	</xsl:template>
</xsl:stylesheet>
